@@ -10,27 +10,28 @@ setMethod (
     signature(data = "db.obj"),
     function (data, INDICES, FUN, ..., simplify = TRUE) {
         if (is.list(INDICES))
-            ## indx <- Reduce(cbind2, INDICES[-1], INDICES[[1]])
             indx <- .combine.list(INDICES)
         else
             indx <- INDICES
-        v <- lk(indx, 1, array = FALSE)
+        v <- lk(as.character(indx, array = FALSE), 1, array = FALSE)
         add.quotes <- function (str)
             unlist(Map(function (x)
                        if (is.character(x)) paste("\"", x, "\"", sep = "")
                        else x, str))
         v <- add.quotes(v)
+
         get.piece <- function (x, indx, v) {
-            s <- paste(gsub("\"", "`", indx@.expr), "==", v, sep = "",
-                       collapse = " && ")
-            for (i in which(is.na(v)))
-                s <- gsub(paste(gsub("\"", "`", indx@.expr[i]), "==", v[i],
-                                sep = ""),
-                          paste("is.na(", indx@.expr[i], ")", sep = ""), s)
-            eval(parse(text = paste("with(x, x[", s, ",])",
-                       sep = "")))
+            eval(parse(
+                text = paste("x[",
+                paste(ifelse(
+                    is.na(v),
+                    paste("is.na(indx[,", seq_len(length(v)), "])", sep = ""),
+                    paste("indx[,", seq_len(length(v)), "] == ", v, sep = "")),
+                      collapse = " & "),
+                ",]")))
         }
-        use <- get.piece(data, indx, v)
+
+        use <- get.piece(data, as.character(indx), v)
         fit0 <- FUN(use)
         if (!is(fit0, "db.obj")) {
             vals <- lk(unique(db.array(as.character(indx, array = FALSE))))
@@ -44,7 +45,8 @@ setMethod (
                     rst[[1]]$index <- vals[i,]
                     next
                 }
-                use <- get.piece(data, indx, w)
+
+                use <- get.piece(data, as.character(indx), w)
                 rst[[count+1]] <- list(index = vals[i,], result = FUN(use))
                 count <- count + 1
             }
