@@ -20,8 +20,8 @@
     ## second is the index for db list
     ## It maps conn.id to the connection object stored
     ## in .localVars$db
-    .localVars$conn.id <- integer(0) 
-    
+    .localVars$conn.id <- integer(0)
+
     ## R connection package
     ## right now, only support RPostgreSQL
     ## set up records for which connection ID belongs to which connection type
@@ -36,5 +36,5 @@
     .localVars$R.ver <- gsub("^R version (\\d+\\.\\d+).*$", "\\1", R.version.string)
     .localVars$pkg.path <- .get.package.path()
     ## source(paste(.localVars$pkg.path, "/auto/enable.cbind2.R", sep = ""))
-    eval(parse(text = "methods:::bind_activation(on = TRUE)"))
+    ## eval(parse(text = "methods:::bind_activation(on = TRUE)"))
 }
